@@ -1,4 +1,6 @@
 from gwaslab.getsig import getsig
 from gwaslab.manhattan import mplot
 from gwaslab.qqplot import qqplot
-from gwaslab.qqplot import gc
\ No newline at end of file
+from gwaslab.qqplot import gc
+from gwaslab.get_hapmap3 import ldsc
+from gwaslab.h2_conversion import h2_obs_to_liab
\ No newline at end of file
